#!python
from .readme import *
from .contrib import *
from .issues import *
from .pull_requests import *
from .conduct import *
from .gitignore import *
from .feature_requests import *
from .bug_report import *
from .licences import *
from .workflows import *
from .funding import *
from .colors import LanguageColorMap
from .gitattributes import *
from .mailmap import *

if __name__ == "__main__":
    print("Run initgitdoc instead!")
